@@ -31,7 +31,7 @@ static void nm_edit_net_init_main_windows(bool redraw);
 static void nm_edit_net_init_edit_windows(nm_form_t *form);
 static void nm_edit_net_fields_setup(const nm_vmctl_data_t *vm,
         size_t if_idx, bool add);
-static size_t nm_edit_net_labels_setup();
+static size_t nm_edit_net_labels_setup(void);
 static int nm_edit_net_get_data(const nm_str_t *name,
         nm_iface_t *ifp, bool add);
 static void nm_edit_net_update_db(const nm_str_t *name,
@@ -86,8 +86,10 @@ static void nm_edit_net_init_edit_windows(nm_form_t *form)
     if (form) {
         nm_form_window_init();
         nm_form_data_t *form_data = (nm_form_data_t *)form_userptr(form);
-        if (form_data)
+
+        if (form_data) {
             form_data->parent_window = action_window;
+        }
     } else {
         werase(action_window);
         werase(help_window);
@@ -138,6 +140,7 @@ void nm_edit_net(const nm_str_t *name)
         case NM_KEY_R:
             {
                 int ans = nm_notify(_(NM_MSG_DELETE));
+
                 if (ans == 'y') {
                     if (nm_edit_net_unplug(name, &vm, ifs.highlight) == NM_OK) {
                         nm_vmctl_free_data(&vm);
@@ -158,6 +161,7 @@ void nm_edit_net(const nm_str_t *name)
 
         if (regen_data) {
             size_t iface_count = 0;
+
             nm_vect_free(&ifaces, NULL);
             nm_vmctl_free_data(&vm);
             nm_vmctl_get_data(name, &vm);
@@ -181,6 +185,7 @@ void nm_edit_net(const nm_str_t *name)
 
             for (size_t n = 0; n < iface_count; n++) {
                 size_t idx_shift = NM_IFS_IDX_COUNT * n;
+
                 nm_vect_insert(&ifaces,
                                nm_vect_str_ctx(&vm.ifs,
                                    NM_SQL_IF_NAME + idx_shift),
@@ -206,6 +211,7 @@ void nm_edit_net(const nm_str_t *name)
 
         if (redraw_window) {
             size_t iface_count = vm.ifs.n_memb / NM_IFS_IDX_COUNT;
+
             nm_edit_net_init_main_windows(true);
 
             nic_list_len = (getmaxy(side_window) - 4);
@@ -233,9 +239,11 @@ void nm_edit_net(const nm_str_t *name)
 static void
 nm_edit_net_plug(const nm_str_t *name, nm_iface_t *ifp)
 {
-#if defined (NM_OS_LINUX)
-    /* If we need to setup IPv4 address or altname we must create
-     * the tap interface yourself. */
+#if defined(NM_OS_LINUX)
+    /*
+     * If we need to setup IPv4 address or altname we must create
+     * the tap interface yourself.
+     */
     if (ifp->ipv4.len && (nm_str_cmp_st(&ifp->macvtap, "no") == NM_OK)) {
         nm_net_add_tap(&ifp->name);
         nm_net_set_ipaddr(&ifp->name, &ifp->ipv4);
@@ -253,8 +261,9 @@ nm_edit_net_plug(const nm_str_t *name, nm_iface_t *ifp)
                     NM_MACVTAP_BRIDGE_MODE : NM_MACVTAP_PRIVATE_MODE);
         }
         tap_idx = nm_net_iface_idx(&ifp->name);
-        if (tap_idx == 0)
+        if (tap_idx == 0) {
             nm_bug("%s: MacVTap interface not found", __func__);
+        }
 
         nm_str_format(&tap_path, "/dev/tap%u", tap_idx);
         /* wait for udev fixes permissions on /dev/tapN */
@@ -312,10 +321,11 @@ nm_edit_net_unplug(const nm_str_t *name, const nm_vmctl_data_t *vm,
     }
 
     if_name = nm_vect_str(&vm->ifs, NM_SQL_IF_NAME + idx_shift);
-    nm_str_format(&query, NM_DEL_IFACE_SQL, name->data, if_name->data);
+    nm_str_format(&query, NM_SQL_IFACES_DELETE, name->data, if_name->data);
     nm_db_edit(query.data);
-#if defined NM_OS_LINUX
+#if defined(NM_OS_LINUX)
     uint32_t tap_idx = nm_net_iface_idx(if_name);
+
     if (tap_idx != 0) { /* iface exist */
         /* detect iface type */
         struct stat tap_info;
@@ -373,7 +383,8 @@ nm_edit_net_action(const nm_str_t *name, const nm_vmctl_data_t *vm,
     msg_len = nm_edit_net_labels_setup();
 
     form_data = nm_form_data_new(
-        action_window, nm_edit_net_init_edit_windows, msg_len, NM_FLD_COUNT / 2, NM_TRUE);
+        action_window, nm_edit_net_init_edit_windows, msg_len,
+        NM_FLD_COUNT / 2, NM_TRUE);
 
     if (nm_form_data_update(form_data, 0, 0) != NM_OK) {
         rc = NM_ERR;
@@ -382,46 +393,46 @@ nm_edit_net_action(const nm_str_t *name, const nm_vmctl_data_t *vm,
 
     for (size_t n = 0; n < NM_FLD_COUNT; n++) {
         switch (n) {
-            case NM_FLD_NAME:
-                fields[n] = nm_field_regexp_new(n / 2, form_data,
-                        "^[a-zA-Z0-9_]{1,15} *$");
-                break;
-            case NM_FLD_NDRV:
-                fields[n] = nm_field_enum_new(
-                    n / 2, form_data, nm_form_net_drv, false, false);
-                break;
-            case NM_FLD_MADR:
-                fields[n] = nm_field_regexp_new(n / 2, form_data, ".*");
-                break;
-            case NM_FLD_IPV4:
-                fields[n] = nm_field_regexp_new(n / 2, form_data, ".*");
-                break;
+        case NM_FLD_NAME:
+            fields[n] = nm_field_regexp_new(n / 2, form_data,
+                    "^[a-zA-Z0-9_]{1,15} *$");
+            break;
+        case NM_FLD_NDRV:
+            fields[n] = nm_field_enum_new(
+                n / 2, form_data, nm_form_net_drv, false, false);
+            break;
+        case NM_FLD_MADR:
+            fields[n] = nm_field_regexp_new(n / 2, form_data, ".*");
+            break;
+        case NM_FLD_IPV4:
+            fields[n] = nm_field_regexp_new(n / 2, form_data, ".*");
+            break;
 #if defined (NM_OS_LINUX)
-            case NM_FLD_VHST:
-                fields[n] = nm_field_enum_new(
-                    n / 2, form_data, nm_form_yes_no, false, false);
-                break;
-            case NM_FLD_MTAP:
-                fields[n] = nm_field_enum_new(
-                    n / 2, form_data, nm_form_macvtap, false, false);
-                break;
-            case NM_FLD_PETH:
-                fields[n] = nm_field_regexp_new(n / 2, form_data, ".*");
-                break;
+        case NM_FLD_VHST:
+            fields[n] = nm_field_enum_new(
+                n / 2, form_data, nm_form_yes_no, false, false);
+            break;
+        case NM_FLD_MTAP:
+            fields[n] = nm_field_enum_new(
+                n / 2, form_data, nm_form_macvtap, false, false);
+            break;
+        case NM_FLD_PETH:
+            fields[n] = nm_field_regexp_new(n / 2, form_data, ".*");
+            break;
 #endif
-            case NM_FLD_USER:
-                fields[n] = nm_field_enum_new(
-                    n / 2, form_data, nm_form_yes_no, false, false);
-                break;
-            case NM_FLD_FWD:
-                fields[n] = nm_field_regexp_new(n / 2, form_data, ".*");
-                break;
-            case NM_FLD_SMB:
-                fields[n] = nm_field_regexp_new(n / 2, form_data, "^/.*");
-                break;
-            default:
-                fields[n] = nm_field_label_new(n / 2, form_data);
-                break;
+        case NM_FLD_USER:
+            fields[n] = nm_field_enum_new(
+                n / 2, form_data, nm_form_yes_no, false, false);
+            break;
+        case NM_FLD_FWD:
+            fields[n] = nm_field_regexp_new(n / 2, form_data, ".*");
+            break;
+        case NM_FLD_SMB:
+            fields[n] = nm_field_regexp_new(n / 2, form_data, "^/.*");
+            break;
+        default:
+            fields[n] = nm_field_label_new(n / 2, form_data);
+            break;
         }
     }
     fields[NM_FLD_COUNT] = NULL;
@@ -468,8 +479,9 @@ nm_edit_net_fields_setup(const nm_vmctl_data_t *vm, size_t if_idx, bool add)
     size_t mvtap_idx = 0;
     size_t idx_shift;
 
-    if (!if_idx)
+    if (!if_idx) {
         return;
+    }
     idx_shift = NM_IFS_IDX_COUNT * (--if_idx);
 
     field_opts_off(fields[NM_FLD_NAME], O_STATIC);
@@ -482,6 +494,7 @@ nm_edit_net_fields_setup(const nm_vmctl_data_t *vm, size_t if_idx, bool add)
     if (add) {
         uint64_t last_mac = nm_form_get_last_mac();
         nm_str_t maddr = NM_INIT_STR;
+
         last_mac++;
         nm_net_mac_n2s(last_mac, &maddr);
         set_field_buffer(fields[NM_FLD_MADR], 0, maddr.data);
@@ -511,9 +524,11 @@ nm_edit_net_fields_setup(const nm_vmctl_data_t *vm, size_t if_idx, bool add)
         (nm_str_cmp_st(nm_vect_str(&vm->ifs, NM_SQL_IF_VHO + idx_shift),
             NM_ENABLE) == NM_OK) ? "yes" : "no");
 
-    mvtap_idx = nm_str_stoui(nm_vect_str(&vm->ifs, NM_SQL_IF_MVT + idx_shift), 10);
-    if (mvtap_idx > NM_NET_MACVTAP_NUM)
+    mvtap_idx = nm_str_stoui(nm_vect_str(&vm->ifs,
+                NM_SQL_IF_MVT + idx_shift), 10);
+    if (mvtap_idx > NM_NET_MACVTAP_NUM) {
         nm_bug("%s: invalid macvtap array index: %zu", __func__, mvtap_idx);
+    }
     set_field_buffer(fields[NM_FLD_MTAP], 0, nm_form_macvtap[mvtap_idx]);
     if (nm_vect_str_len(&vm->ifs, NM_SQL_IF_PET + idx_shift) > 0) {
         set_field_buffer(fields[NM_FLD_PETH], 0,
@@ -523,7 +538,8 @@ nm_edit_net_fields_setup(const nm_vmctl_data_t *vm, size_t if_idx, bool add)
     (void) mvtap_idx;
 #endif
     set_field_buffer(fields[NM_FLD_USER], 0,
-        (nm_str_cmp_st(nm_vect_str(&vm->ifs, NM_SQL_IF_USR + idx_shift), NM_ENABLE) == NM_OK) ?
+        (nm_str_cmp_st(nm_vect_str(&vm->ifs, NM_SQL_IF_USR + idx_shift),
+                       NM_ENABLE) == NM_OK) ?
         nm_form_yes_no[0] : nm_form_yes_no[1]);
     if (nm_vect_str_len(&vm->ifs, NM_SQL_IF_FWD + idx_shift) > 0) {
         set_field_buffer(fields[NM_FLD_FWD], 0,
@@ -535,7 +551,7 @@ nm_edit_net_fields_setup(const nm_vmctl_data_t *vm, size_t if_idx, bool add)
     }
 }
 
-static size_t nm_edit_net_labels_setup()
+static size_t nm_edit_net_labels_setup(void)
 {
     nm_str_t buf = NM_INIT_STR;
     size_t max_label_len = 0;
@@ -580,11 +596,13 @@ static size_t nm_edit_net_labels_setup()
         }
 
         msg_len = mbstowcs(NULL, buf.data, buf.len);
-        if (msg_len > max_label_len)
+        if (msg_len > max_label_len) {
             max_label_len = msg_len;
+        }
 
-        if (fields[n])
+        if (fields[n]) {
             set_field_buffer(fields[n], 0, buf.data);
+        }
     }
 
     nm_str_free(&buf);
@@ -615,23 +633,30 @@ nm_edit_net_get_data(const nm_str_t *name, nm_iface_t *ifp, bool add)
     nm_get_field_buf(fields[NM_FLD_FWD], &ifp->hostfwd);
     nm_get_field_buf(fields[NM_FLD_SMB], &ifp->smb);
 
-    if (field_status(fields[NM_FLD_NAME]))
+    if (field_status(fields[NM_FLD_NAME])) {
         nm_form_check_data(_("Interface name"), ifp->name, err);
-    if (field_status(fields[NM_FLD_NDRV]))
+    }
+    if (field_status(fields[NM_FLD_NDRV])) {
         nm_form_check_data(_("Net driver"), ifp->drv, err);
-    if (field_status(fields[NM_FLD_MADR]))
+    }
+    if (field_status(fields[NM_FLD_MADR])) {
         nm_form_check_data(_("Mac address"), ifp->maddr, err);
+    }
 #if defined (NM_OS_LINUX)
-    if (field_status(fields[NM_FLD_VHST]))
+    if (field_status(fields[NM_FLD_VHST])) {
         nm_form_check_data(_("Enable vhost"), ifp->vhost, err);
-    if (field_status(fields[NM_FLD_MTAP]))
+    }
+    if (field_status(fields[NM_FLD_MTAP])) {
         nm_form_check_data(_("Enable MacVTap"), ifp->macvtap, err);
+    }
 #endif
-    if (field_status(fields[NM_FLD_USER]))
+    if (field_status(fields[NM_FLD_USER])) {
         nm_form_check_data(_("User mode"), ifp->netuser, err);
+    }
 
-    if ((rc = nm_print_empty_fields(&err)) == NM_ERR)
+    if ((rc = nm_print_empty_fields(&err)) == NM_ERR) {
         goto out;
+    }
 
     if (field_status(fields[NM_FLD_MADR])) {
         if (nm_net_verify_mac(&ifp->maddr) != NM_OK) {
@@ -670,6 +695,7 @@ nm_edit_net_get_data(const nm_str_t *name, nm_iface_t *ifp, bool add)
 
     if ((field_status(fields[NM_FLD_IPV4])) && (ifp->ipv4.len > 0)) {
         nm_str_t err_msg = NM_INIT_STR;
+
         if (nm_net_verify_ipaddr4(&ifp->ipv4, NULL, &err_msg) != NM_OK) {
             nm_warn(err_msg.data);
             rc = NM_ERR;
@@ -685,18 +711,20 @@ nm_edit_net_get_data(const nm_str_t *name, nm_iface_t *ifp, bool add)
         int vhost_ok = 1;
 
         if (field_status(fields[NM_FLD_NDRV])) {
-            if (nm_str_cmp_st(&ifp->drv, NM_DEFAULT_NETDRV) != NM_OK)
+            if (nm_str_cmp_st(&ifp->drv, NM_DEFAULT_NETDRV) != NM_OK) {
                 vhost_ok = 0;
+            }
         } else {
             nm_str_t query = NM_INIT_STR;
             nm_vect_t netv = NM_INIT_VECT;
 
-            nm_str_format(&query, NM_GET_IFACE_SQL,
+            nm_str_format(&query, NM_SQL_IFACES_SELECT_ID,
                 name->data, ifp->name.data, NM_DEFAULT_NETDRV);
             nm_db_select(query.data, &netv);
 
-            if (netv.n_memb == 0)
+            if (netv.n_memb == 0) {
                 vhost_ok = 0;
+            }
 
             nm_vect_free(&netv, nm_str_vect_free_cb);
             nm_str_free(&query);
@@ -732,56 +760,59 @@ nm_edit_net_update_db(const nm_str_t *name, nm_iface_t *ifp, bool add)
     nm_str_t query = NM_INIT_STR;
 
     if (add) {
-        nm_str_format(&query,
-            "INSERT INTO ifaces(vm_name, if_name) VALUES('%s', '%s')",
-            name->data, ifp->name.data);
+        nm_str_format(&query, NM_SQL_IFACES_INSERT_NEW,
+                name->data,
+                ifp->name.data,
+                "",
+                NM_DEFAULT_NETDRV,
+#if defined(NM_OS_LINUX)
+                NM_ENABLE,
+#else
+                NM_DISABLE,
+#endif
+                NM_DISABLE, "", NM_DISABLE);
         nm_db_edit(query.data);
     } else {
         if (field_status(fields[NM_FLD_NAME])) {
-            nm_str_format(&query,
-                "UPDATE ifaces SET if_name='%s' WHERE vm_name='%s' AND if_name='%s'",
-                ifp->name.data, name->data, ifp->oldname.data);
+            nm_str_format(&query, NM_SQL_IFACES_UPDATE_NAME,
+                    ifp->name.data, name->data, ifp->oldname.data);
             nm_db_edit(query.data);
         }
     }
 
     if (field_status(fields[NM_FLD_NDRV]) || add) {
-        nm_str_format(&query,
-            "UPDATE ifaces SET if_drv='%s' WHERE vm_name='%s' AND if_name='%s'",
-            ifp->drv.data, name->data, ifp->name.data);
+        nm_str_format(&query, NM_SQL_IFACES_UPDATE_DRV,
+                ifp->drv.data, name->data, ifp->name.data);
         nm_db_edit(query.data);
 
-#if defined (NM_OS_LINUX)
+#if defined(NM_OS_LINUX)
         /* disable vhost if driver is not virtio-net */
         if (nm_str_cmp_st(&ifp->drv, NM_DEFAULT_NETDRV) != NM_OK) {
-            nm_str_format(&query,
-                "UPDATE ifaces SET vhost='0' WHERE vm_name='%s' AND if_name='%s'",
-                name->data, ifp->name.data);
+            nm_str_format(&query, NM_SQL_IFACES_UPDATE_VHOST,
+                    NM_DISABLE, name->data, ifp->name.data);
             nm_db_edit(query.data);
         }
 #endif
     }
 
     if (field_status(fields[NM_FLD_MADR]) || add) {
-        nm_str_format(&query,
-            "UPDATE ifaces SET mac_addr='%s' WHERE vm_name='%s' AND if_name='%s'",
-            ifp->maddr.data, name->data, ifp->name.data);
+        nm_str_format(&query, NM_SQL_IFACES_UPDATE_MADDR,
+                ifp->maddr.data, name->data, ifp->name.data);
         nm_db_edit(query.data);
     }
 
     if (field_status(fields[NM_FLD_IPV4]) || add) {
-        nm_str_format(&query,
-            "UPDATE ifaces SET ipv4_addr='%s' WHERE vm_name='%s' AND if_name='%s'",
-            ifp->ipv4.data, name->data, ifp->name.data);
+        nm_str_format(&query, NM_SQL_IFACES_UPDATE_IPV4,
+                ifp->ipv4.data, name->data, ifp->name.data);
         nm_db_edit(query.data);
     }
 
 #if defined (NM_OS_LINUX)
     if (field_status(fields[NM_FLD_VHST]) || add) {
-        nm_str_format(&query,
-            "UPDATE ifaces SET vhost='%s' WHERE vm_name='%s' AND if_name='%s'",
-            (nm_str_cmp_st(&ifp->vhost, "yes") == NM_OK) ? NM_ENABLE : NM_DISABLE,
-            name->data, ifp->name.data);
+        nm_str_format(&query, NM_SQL_IFACES_UPDATE_VHOST,
+                (nm_str_cmp_st(&ifp->vhost, "yes") == NM_OK) ?
+                NM_ENABLE : NM_DISABLE,
+                name->data, ifp->name.data);
         nm_db_edit(query.data);
     }
 
@@ -796,41 +827,37 @@ nm_edit_net_update_db(const nm_str_t *name, nm_iface_t *ifp, bool add)
             }
         }
 
-        if (macvtap_idx == -1)
+        if (macvtap_idx == -1) {
             nm_bug("%s: macvtap_idx is not found", __func__);
+        }
 
-        nm_str_format(&query,
-            "UPDATE ifaces SET macvtap='%zd' WHERE vm_name='%s' AND if_name='%s'",
+        nm_str_format(&query, NM_SQL_IFACES_UPDATE_MACVTAP,
             macvtap_idx, name->data, ifp->name.data);
         nm_db_edit(query.data);
     }
 
     if (field_status(fields[NM_FLD_PETH]) || add) {
-        nm_str_format(&query,
-            "UPDATE ifaces SET parent_eth='%s' WHERE vm_name='%s' AND if_name='%s'",
+        nm_str_format(&query, NM_SQL_IFACES_UPDATE_PARENT,
             ifp->parent_eth.data, name->data, ifp->name.data);
         nm_db_edit(query.data);
     }
 #endif
 
     if (field_status(fields[NM_FLD_USER]) || add) {
-        nm_str_format(&query,
-            "UPDATE ifaces SET netuser='%s' WHERE vm_name='%s' AND if_name='%s'",
+        nm_str_format(&query, NM_SQL_IFACES_UPDATE_USERNET,
             (nm_str_cmp_st(&ifp->netuser, "yes") == NM_OK) ?
             NM_ENABLE : NM_DISABLE, name->data, ifp->name.data);
         nm_db_edit(query.data);
     }
 
     if (field_status(fields[NM_FLD_FWD]) || add) {
-        nm_str_format(&query,
-            "UPDATE ifaces SET hostfwd='%s' WHERE vm_name='%s' AND if_name='%s'",
+        nm_str_format(&query, NM_SQL_IFACES_UPDATE_HOSTFWD,
             ifp->hostfwd.data, name->data, ifp->name.data);
         nm_db_edit(query.data);
     }
 
     if (field_status(fields[NM_FLD_SMB]) || add) {
-        nm_str_format(&query,
-            "UPDATE ifaces SET smb='%s' WHERE vm_name='%s' AND if_name='%s'",
+        nm_str_format(&query, NM_SQL_IFACES_UPDATE_SMB,
             ifp->smb.data, name->data, ifp->name.data);
         nm_db_edit(query.data);
     }
@@ -861,7 +888,7 @@ static int nm_edit_net_maddr_busy(const nm_str_t *mac)
     int rc = NM_OK;
     nm_vect_t maddrs = NM_INIT_VECT;
 
-    nm_db_select(NM_GET_IFACES_MACS, &maddrs);
+    nm_db_select(NM_SQL_IFACES_SELECT_MAC, &maddrs);
 
     for (size_t n = 0; n < maddrs.n_memb; n++) {
         if (nm_str_cmp_ss(mac, nm_vect_str(&maddrs, n)) == NM_OK) {
@@ -881,7 +908,7 @@ static bool nm_check_nic_name_busy(const nm_str_t *name)
     nm_str_t query = NM_INIT_STR;
     bool rc = false;
 
-    nm_str_format(&query, NM_GET_IFACES_NAMES, name->data);
+    nm_str_format(&query, NM_SQL_IFACES_SELECT_ID_BY_NAME, name->data);
     nm_db_select(query.data, &names);
     if (names.n_memb > 0) {
         rc = true;
@@ -926,8 +953,10 @@ static int nm_verify_port(const char *port, size_t *len)
     return rc;
 }
 
-/* Verify portfwd value
- * Format: tcp|udp::[1-65535]-:[1-65535]  */
+/*
+ * Verify portfwd value
+ * Format: tcp|udp::[1-65535]-:[1-65535]
+ */
 static int nm_verify_portfwd(const nm_str_t *fwd)
 {
     char proto[4] = {0};
