@@ -1,6 +1,6 @@
 #include <nm_core.h>
 
-#if defined (NM_WITH_OVF_SUPPORT)
+#if defined(NM_WITH_OVF_SUPPORT)
 #include <nm_form.h>
 #include <nm_utils.h>
 #include <nm_string.h>
@@ -40,52 +40,54 @@ static const char NM_LC_OVF_FORM_VER[]  = "OVF version";
 static const char NM_XML_OVF_NS[]    = "ovf";
 static const char NM_XML_RASD_NS[]   = "rasd";
 static const char NM_XML_SASD_NS[]   = "sasd";
-static const char NM_XML_OVF1_HREF[]  = "http://schemas.dmtf.org/ovf/envelope/1";
-static const char NM_XML_OVF2_HREF[]  = "http://schemas.dmtf.org/ovf/envelope/2";
+static const char NM_XML_OVF1_HREF[] = "http://schemas.dmtf.org/ovf/envelope/1";
+static const char NM_XML_OVF2_HREF[] = "http://schemas.dmtf.org/ovf/envelope/2";
 
-static const char NM_XML_RASD_HREF[] = \
-    "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_ResourceAllocationSettingData";
+static const char NM_XML_RASD_HREF[] =
+    "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/"
+    "CIM_ResourceAllocationSettingData";
 
-static const char NM_XML_SASD_HREF[] = \
-    "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_StorageAllocationSettingData.xsd";
+static const char NM_XML_SASD_HREF[] =
+    "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/"
+    "CIM_StorageAllocationSettingData.xsd";
 
-static const char NM_XPATH_NAME[] = \
+static const char NM_XPATH_NAME[] =
     "/ovf:Envelope/ovf:VirtualSystem/ovf:Name/text()";
 
-static const char NM_XPATH_MEM[] = \
-    "/ovf:Envelope/ovf:VirtualSystem/ovf:VirtualHardwareSection/" \
+static const char NM_XPATH_MEM[] =
+    "/ovf:Envelope/ovf:VirtualSystem/ovf:VirtualHardwareSection/"
     "ovf:Item[rasd:ResourceType/text()=4]/rasd:VirtualQuantity/text()";
 
-static const char NM_XPATH_NCPU[] = \
-    "/ovf:Envelope/ovf:VirtualSystem/ovf:VirtualHardwareSection/" \
+static const char NM_XPATH_NCPU[] =
+    "/ovf:Envelope/ovf:VirtualSystem/ovf:VirtualHardwareSection/"
     "ovf:Item[rasd:ResourceType/text()=3]/rasd:VirtualQuantity/text()";
 
-static const char NM_XPATH_DRIVE_ID1[] = \
-    "/ovf:Envelope/ovf:VirtualSystem/ovf:VirtualHardwareSection/" \
+static const char NM_XPATH_DRIVE_ID1[] =
+    "/ovf:Envelope/ovf:VirtualSystem/ovf:VirtualHardwareSection/"
     "ovf:Item[rasd:ResourceType/text()=17]/rasd:HostResource/text()";
 
-static const char NM_XPATH_DRIVE_ID2[] = \
-    "/ovf:Envelope/ovf:VirtualSystem/ovf:VirtualHardwareSection/" \
+static const char NM_XPATH_DRIVE_ID2[] =
+    "/ovf:Envelope/ovf:VirtualSystem/ovf:VirtualHardwareSection/"
     "ovf:StorageItem[sasd:ResourceType/text()=17]/sasd:HostResource/text()";
 
-static const char NM_XPATH_DRIVE_REF[] = \
-    "/ovf:Envelope/ovf:DiskSection/" \
+static const char NM_XPATH_DRIVE_REF[] =
+    "/ovf:Envelope/ovf:DiskSection/"
     "ovf:Disk[@ovf:diskId=\"%s\"]/@ovf:fileRef";
 
-static const char NM_XPATH_DRIVE_CAP[] = \
-    "/ovf:Envelope/ovf:DiskSection/" \
+static const char NM_XPATH_DRIVE_CAP[] =
+    "/ovf:Envelope/ovf:DiskSection/"
     "ovf:Disk[@ovf:diskId=\"%s\"]/@ovf:capacity";
 
-static const char NM_XPATH_DRIVE_HREF[] = \
-    "/ovf:Envelope/ovf:References/" \
+static const char NM_XPATH_DRIVE_HREF[] =
+    "/ovf:Envelope/ovf:References/"
     "ovf:File[@ovf:id=\"%s\"]/@ovf:href";
 
-static const char NM_XPATH_NETH[] = \
-    "/ovf:Envelope/ovf:VirtualSystem/ovf:VirtualHardwareSection/" \
+static const char NM_XPATH_NETH[] =
+    "/ovf:Envelope/ovf:VirtualSystem/ovf:VirtualHardwareSection/"
     "ovf:Item[rasd:ResourceType/text()=10]";
 
-static const char NM_XPATH_USB_EHCI[] = \
-    "/ovf:Envelope/ovf:VirtualSystem/ovf:VirtualHardwareSection/" \
+static const char NM_XPATH_USB_EHCI[] =
+    "/ovf:Envelope/ovf:VirtualSystem/ovf:VirtualHardwareSection/"
     "ovf:Item[rasd:ResourceType/text()=23]";
 
 typedef struct archive nm_archive_t;
@@ -102,8 +104,8 @@ void nm_drive_vect_ins_cb(void *unit_p, const void *ctx);
 void nm_drive_vect_free_cb(void *unit_p);
 
 static void nm_ovf_init_windows(nm_form_t *form);
-static void nm_ovf_fields_setup();
-static size_t nm_ovf_labels_setup();
+static void nm_ovf_fields_setup(void);
+static size_t nm_ovf_labels_setup(void);
 static int nm_clean_temp_dir(const char *tmp_dir, const nm_vect_t *files);
 static void nm_archive_copy_data(nm_archive_t *in, nm_archive_t *out);
 static void nm_ovf_extract(const nm_str_t *ova_path, const char *tmp_dir,
@@ -145,8 +147,10 @@ static void nm_ovf_init_windows(nm_form_t *form)
     if (form) {
         nm_form_window_init();
         nm_form_data_t *form_data = (nm_form_data_t *)form_userptr(form);
-        if (form_data)
+
+        if (form_data) {
             form_data->parent_window = action_window;
+        }
     } else {
         werase(action_window);
         werase(help_window);
@@ -212,29 +216,30 @@ void nm_ovf_import(void)
     form_data = nm_form_data_new(
         action_window, nm_ovf_init_windows, msg_len, NM_FLD_COUNT / 2, NM_TRUE);
 
-    if (nm_form_data_update(form_data, 0, 0) != NM_OK)
+    if (nm_form_data_update(form_data, 0, 0) != NM_OK) {
         goto out;
+    }
 
     for (size_t n = 0; n < NM_FLD_COUNT; n++) {
         switch (n) {
-            case NM_OVA_FLD_SRC:
-                fields[n] = nm_field_regexp_new(n / 2, form_data, "^/.*");
-                break;
-            case NM_OVA_FLD_ARCH:
-                fields[n] = nm_field_enum_new(
-                    n / 2, form_data, nm_cfg_get_arch(), false, false);
-                break;
-            case NM_OVA_FLD_NAME:
-                fields[n] = nm_field_regexp_new(
-                    n / 2, form_data, "^[a-zA-Z0-9_-]{1,30} *$");
-                break;
-            case NM_OVA_FLD_VER:
-                fields[n] = nm_field_enum_new(
-                    n / 2, form_data, nm_ovf_version, false, false);
-                break;
-            default:
-                fields[n] = nm_field_label_new(n / 2, form_data);
-                break;
+        case NM_OVA_FLD_SRC:
+            fields[n] = nm_field_regexp_new(n / 2, form_data, "^/.*");
+            break;
+        case NM_OVA_FLD_ARCH:
+            fields[n] = nm_field_enum_new(
+                n / 2, form_data, nm_cfg_get_arch(), false, false);
+            break;
+        case NM_OVA_FLD_NAME:
+            fields[n] = nm_field_regexp_new(
+                n / 2, form_data, "^[a-zA-Z0-9_-]{1,30} *$");
+            break;
+        case NM_OVA_FLD_VER:
+            fields[n] = nm_field_enum_new(
+                n / 2, form_data, nm_ovf_version, false, false);
+            break;
+        default:
+            fields[n] = nm_field_label_new(n / 2, form_data);
+            break;
         }
     }
     fields[NM_FLD_COUNT] = NULL;
@@ -246,19 +251,24 @@ void nm_ovf_import(void)
     form = nm_form_new(form_data, fields);
     nm_form_post(form);
 
-    if (nm_form_draw(&form) != NM_OK)
+    if (nm_form_draw(&form) != NM_OK) {
         goto cancel;
+    }
 
-    if (nm_ova_get_data(&vm, &version) != NM_OK)
+    if (nm_ova_get_data(&vm, &version) != NM_OK) {
         goto cancel;
+    }
 
     sp_data.stop = &done;
 
-    if (pthread_create(&spin_th, NULL, nm_progress_bar, (void *) &sp_data) != 0)
+    if (pthread_create(&spin_th, NULL, nm_progress_bar,
+                (void *) &sp_data) != 0) {
         nm_bug(_("%s: cannot create thread"), __func__);
+    }
 
-    if (mkdtemp(templ_path.data) == NULL)
+    if (mkdtemp(templ_path.data) == NULL) {
         nm_bug("%s: mkdtemp error: %s", __func__, strerror(errno));
+    }
 
     nm_ovf_extract(&vm.srcp, templ_path.data, &files);
 
@@ -284,28 +294,33 @@ void nm_ovf_import(void)
         goto out;
     }
 
-    if (vm.name.len == 0)
+    if (vm.name.len == 0) {
         nm_ovf_get_name(&vm.name, xpath_ctx);
+    }
     nm_ovf_get_ncpu(&vm.cpus, xpath_ctx);
     nm_ovf_get_mem(&vm.memo, xpath_ctx);
     nm_ovf_get_drives(&drives, xpath_ctx, version);
     vm.ifs.count = nm_ovf_get_neth(xpath_ctx);
-    if (nm_ovf_get_usb(xpath_ctx))
+    if (nm_ovf_get_usb(xpath_ctx)) {
         vm.usb_enable = 1;
+    }
 
-    if (nm_form_name_used(&vm.name) != NM_OK)
+    if (nm_form_name_used(&vm.name) != NM_OK) {
         goto out;
+    }
 
     nm_ovf_convert_drives(&drives, &vm.name, templ_path.data);
     nm_ovf_to_db(&vm, &drives);
 
 out:
     done = 1;
-    if (spin_th && (pthread_join(spin_th, NULL) != 0))
+    if (spin_th && (pthread_join(spin_th, NULL) != 0)) {
         nm_bug(_("%s: cannot join thread"), __func__);
+    }
 
-    if (nm_clean_temp_dir(templ_path.data, &files) != NM_OK)
+    if (nm_clean_temp_dir(templ_path.data, &files) != NM_OK) {
         nm_warn(_(NM_MSG_INC_DEL));
+    }
 
     xmlXPathFreeContext(xpath_ctx);
     xmlFreeDoc(doc);
@@ -323,15 +338,16 @@ cancel:
     nm_vm_free(&vm);
 }
 
-static void nm_ovf_fields_setup()
+static void nm_ovf_fields_setup(void)
 {
-    set_field_buffer(fields[NM_OVA_FLD_ARCH], 0, *nm_cfg_get()->qemu_targets.data);
+    set_field_buffer(fields[NM_OVA_FLD_ARCH], 0,
+            *nm_cfg_get()->qemu_targets.data);
     set_field_buffer(fields[NM_OVA_FLD_VER], 0, *nm_ovf_version);
     field_opts_off(fields[NM_OVA_FLD_SRC], O_STATIC);
     field_opts_off(fields[NM_OVA_FLD_NAME], O_STATIC);
 }
 
-static size_t nm_ovf_labels_setup()
+static size_t nm_ovf_labels_setup(void)
 {
     nm_str_t buf = NM_INIT_STR;
     size_t max_label_len = 0;
@@ -356,11 +372,13 @@ static size_t nm_ovf_labels_setup()
         }
 
         msg_len = mbstowcs(NULL, buf.data, buf.len);
-        if (msg_len > max_label_len)
+        if (msg_len > max_label_len) {
             max_label_len = msg_len;
+        }
 
-        if (fields[n])
+        if (fields[n]) {
             set_field_buffer(fields[n], 0, buf.data);
+        }
     }
 
     nm_str_free(&buf);
@@ -380,26 +398,31 @@ static void nm_ovf_extract(const nm_str_t *ova_path, const char *tmp_dir,
     archive_write_disk_set_options(out, 0);
     archive_read_support_format_tar(in);
 
-    if (archive_read_open_filename(in, ova_path->data, NM_BLOCK_SIZE) != 0)
+    if (archive_read_open_filename(in, ova_path->data, NM_BLOCK_SIZE) != 0) {
         nm_bug("%s: ovf read error: %s", __func__, archive_error_string(in));
+    }
 
     /* save current working directory */
-    if (getcwd(cwd, sizeof(cwd)) == NULL)
+    if (getcwd(cwd, sizeof(cwd)) == NULL) {
         nm_bug("%s: getcwd error: %s", __func__, strerror(errno));
+    }
 
     /* change current working directory to temporary */
-    if (chdir(tmp_dir) == -1)
+    if (chdir(tmp_dir) == -1) {
         nm_bug("%s: chdir error: %s", __func__, strerror(errno));
+    }
 
     for (;;) {
         const char *file;
         int rc = archive_read_next_header(in, &ar_entry);
 
-        if (rc == ARCHIVE_EOF)
+        if (rc == ARCHIVE_EOF) {
             break;
+        }
 
-        if (rc != ARCHIVE_OK)
+        if (rc != ARCHIVE_OK) {
             nm_bug("%s: bad archive: %s", __func__, archive_error_string(in));
+        }
 
         file = archive_entry_pathname(ar_entry);
 
@@ -422,8 +445,9 @@ static void nm_ovf_extract(const nm_str_t *ova_path, const char *tmp_dir,
     archive_write_free(out);
 
     /* restore current working directory */
-    if (chdir(cwd) == -1)
+    if (chdir(cwd) == -1) {
         nm_bug("%s: chdir error: %s", __func__, strerror(errno));
+    }
 }
 
 static void nm_archive_copy_data(nm_archive_t *in, nm_archive_t *out)
@@ -439,13 +463,18 @@ static void nm_archive_copy_data(nm_archive_t *in, nm_archive_t *out)
     for (;;) {
         int rc = archive_read_data_block(in, &buf, &size, &offset);
 
-        if (rc == ARCHIVE_EOF)
+        if (rc == ARCHIVE_EOF) {
             break;
-        if (rc != ARCHIVE_OK)
-            nm_bug("%s: error read archive: %s", __func__, archive_error_string(in));
+        }
+        if (rc != ARCHIVE_OK) {
+            nm_bug("%s: error read archive: %s",
+                    __func__, archive_error_string(in));
+        }
 
-        if (archive_write_data_block(out, buf, size, offset) != ARCHIVE_OK)
-            nm_bug("%s: error write archive: %s", __func__, archive_error_string(out));
+        if (archive_write_data_block(out, buf, size, offset) != ARCHIVE_OK) {
+            nm_bug("%s: error write archive: %s",
+                    __func__, archive_error_string(out));
+        }
     }
 }
 
@@ -457,15 +486,17 @@ static int nm_clean_temp_dir(const char *tmp_dir, const nm_vect_t *files)
     for (size_t n = 0; n < files->n_memb; n++) {
         nm_str_format(&path, "%s/%s", tmp_dir, (char *) nm_vect_at(files, n));
 
-        if (unlink(path.data) == -1)
+        if (unlink(path.data) == -1) {
             rc = NM_ERR;
+        }
 
         nm_debug("ova: clean file: %s\n", path.data);
     }
 
     if (rc == NM_OK) {
-        if (rmdir(tmp_dir) == -1)
+        if (rmdir(tmp_dir) == -1) {
             rc = NM_ERR;
+        }
     }
 
     nm_str_free(&path);
@@ -479,11 +510,13 @@ static const char *nm_find_ovf(const nm_vect_t *files)
         const char *file = nm_vect_at(files, n);
         size_t len = strlen(file);
 
-        if (len < 4)
+        if (len < 4) {
             continue;
+        }
 
-        if (nm_str_cmp_tt(file + (len - 4), ".ovf") == NM_OK)
+        if (nm_str_cmp_tt(file + (len - 4), ".ovf") == NM_OK) {
             return file;
+        }
     }
 
     return NULL;
@@ -506,14 +539,19 @@ static nm_xml_doc_pt nm_ovf_open(const char *tmp_dir, const char *ovf_file)
 static int nm_register_xml_ns(nm_xml_xpath_ctx_pt ctx, int version)
 {
     if (version == 1) {
-        if ((__nm_register_xml_ns(ctx, NM_XML_OVF_NS, NM_XML_OVF1_HREF) == NM_ERR) ||
-                (__nm_register_xml_ns(ctx, NM_XML_RASD_NS, NM_XML_RASD_HREF) == NM_ERR)) {
+        if ((__nm_register_xml_ns(ctx, NM_XML_OVF_NS,
+                        NM_XML_OVF1_HREF) == NM_ERR) ||
+                (__nm_register_xml_ns(ctx, NM_XML_RASD_NS,
+                                      NM_XML_RASD_HREF) == NM_ERR)) {
             return NM_ERR;
         }
     } else if (version == 2) {
-        if ((__nm_register_xml_ns(ctx, NM_XML_OVF_NS, NM_XML_OVF2_HREF) == NM_ERR) ||
-                (__nm_register_xml_ns(ctx, NM_XML_SASD_NS, NM_XML_SASD_HREF)) ||
-                (__nm_register_xml_ns(ctx, NM_XML_RASD_NS, NM_XML_RASD_HREF) == NM_ERR)) {
+        if ((__nm_register_xml_ns(ctx, NM_XML_OVF_NS,
+                        NM_XML_OVF2_HREF) == NM_ERR) ||
+                (__nm_register_xml_ns(ctx, NM_XML_SASD_NS,
+                                      NM_XML_SASD_HREF)) ||
+                (__nm_register_xml_ns(ctx, NM_XML_RASD_NS,
+                                      NM_XML_RASD_HREF) == NM_ERR)) {
             return NM_ERR;
         }
     } else {
@@ -532,16 +570,18 @@ static int __nm_register_xml_ns(nm_xml_xpath_ctx_pt ctx, const char *ns,
     nm_xml_char_t *xml_ns;
     nm_xml_char_t *xml_href;
 
-    if ((xml_ns = xmlCharStrdup(ns)) == NULL)
+    if ((xml_ns = xmlCharStrdup(ns)) == NULL) {
         return NM_ERR;
+    }
 
     if ((xml_href = xmlCharStrdup(href)) == NULL) {
         xmlFree(xml_ns);
         return NM_ERR;
     }
 
-    if (xmlXPathRegisterNs(ctx, xml_ns, xml_href) != 0)
+    if (xmlXPathRegisterNs(ctx, xml_ns, xml_href) != 0) {
         rc = NM_ERR;
+    }
 
     xmlFree(xml_ns);
     xmlFree(xml_href);
@@ -555,8 +595,9 @@ static nm_xml_xpath_obj_pt nm_exec_xpath(const char *xpath,
     nm_xml_char_t *xml_xpath;
     nm_xml_xpath_obj_pt obj = NULL;
 
-    if ((xml_xpath = xmlCharStrdup(xpath)) == NULL)
+    if ((xml_xpath = xmlCharStrdup(xpath)) == NULL) {
         return NULL;
+    }
 
     obj = xmlXPathEvalExpression(xml_xpath, ctx);
 
@@ -590,27 +631,32 @@ static void nm_ovf_get_drives(nm_vect_t *drives, nm_xml_xpath_ctx_pt ctx,
     size_t ndrives;
 
     if (version == 1) {
-        if ((obj_id = nm_exec_xpath(NM_XPATH_DRIVE_ID1, ctx)) == NULL)
+        if ((obj_id = nm_exec_xpath(NM_XPATH_DRIVE_ID1, ctx)) == NULL) {
             nm_bug("%s: cannot get drive_id from ovf file", __func__);
+        }
     } else {
-        if ((obj_id = nm_exec_xpath(NM_XPATH_DRIVE_ID2, ctx)) == NULL)
+        if ((obj_id = nm_exec_xpath(NM_XPATH_DRIVE_ID2, ctx)) == NULL) {
             nm_bug("%s: cannot get drive_id from ovf file", __func__);
+        }
     }
 
-    if (!obj_id->nodesetval || ((ndrives = obj_id->nodesetval->nodeNr) == 0))
+    if (!obj_id->nodesetval || ((ndrives = obj_id->nodesetval->nodeNr) == 0)) {
         nm_bug("%s: no drives was found", __func__);
+    }
 
     for (size_t n = 0; n < ndrives; n++) {
         nm_xml_node_pt node_id = obj_id->nodesetval->nodeTab[n];
 
-        if ((node_id->type == XML_TEXT_NODE) || (node_id->type == XML_ATTRIBUTE_NODE)) {
+        if ((node_id->type == XML_TEXT_NODE) ||
+                (node_id->type == XML_ATTRIBUTE_NODE)) {
             nm_xml_char_t *xml_id = xmlNodeGetContent(node_id);
 
             char *id = strrchr((char *) xml_id, '/');
             uint64_t capacity = 0;
 
-            if (id == NULL)
+            if (id == NULL) {
                 nm_bug("%s: NULL disk id", __func__);
+            }
 
             id++;
             nm_debug("ova: drive_id: %s\n", id);
@@ -618,7 +664,8 @@ static void nm_ovf_get_drives(nm_vect_t *drives, nm_xml_xpath_ctx_pt ctx,
             nm_str_format(&xpath, NM_XPATH_DRIVE_CAP, id);
             nm_ovf_get_text(&buf, ctx, xpath.data, "capacity");
             capacity = nm_str_stoul(&buf, 10);
-            nm_str_format(&drive.capacity, "%g", (double) capacity / 1073741824);
+            nm_str_format(&drive.capacity, "%g",
+                    (double) capacity / 1073741824);
 
             nm_str_format(&xpath, NM_XPATH_DRIVE_REF, id);
             nm_ovf_get_text(&buf, ctx, xpath.data, "file ref");
@@ -645,8 +692,9 @@ static uint32_t nm_ovf_get_neth(nm_xml_xpath_ctx_pt ctx)
     uint32_t neth = 0;
     nm_xml_xpath_obj_pt obj;
 
-    if ((obj = nm_exec_xpath(NM_XPATH_NETH, ctx)) == NULL)
+    if ((obj = nm_exec_xpath(NM_XPATH_NETH, ctx)) == NULL) {
         nm_bug("%s: cannot get interfaces from ovf file", __func__);
+    }
 
     neth = obj->nodesetval->nodeNr;
     nm_debug("ova: eth num: %u\n", neth);
@@ -661,12 +709,14 @@ static uint32_t nm_ovf_get_usb(nm_xml_xpath_ctx_pt ctx)
     uint32_t node_num = 0;
     nm_xml_xpath_obj_pt obj;
 
-    if ((obj = nm_exec_xpath(NM_XPATH_USB_EHCI, ctx)) == NULL)
+    if ((obj = nm_exec_xpath(NM_XPATH_USB_EHCI, ctx)) == NULL) {
         nm_bug("%s: cannot get usb settings from ovf file", __func__);
+    }
 
     node_num = obj->nodesetval->nodeNr;
-    if (node_num)
+    if (node_num) {
         nm_debug("ova: USB Controller (EHCI) enabled\n");
+    }
 
     xmlXPathFreeObject(obj);
 
@@ -679,16 +729,19 @@ static void nm_ovf_get_text(nm_str_t *res, nm_xml_xpath_ctx_pt ctx,
     nm_xml_xpath_obj_pt obj;
     nm_xml_node_pt node;
 
-    if ((obj = nm_exec_xpath(xpath, ctx)) == NULL)
+    if ((obj = nm_exec_xpath(xpath, ctx)) == NULL) {
         nm_bug("%s: cannot get %s from ovf file", __func__, param);
+    }
 
-    if (!obj->nodesetval || !obj->nodesetval->nodeNr)
+    if (!obj->nodesetval || !obj->nodesetval->nodeNr) {
         nm_bug("%s: xpath return zero result", __func__);
+    }
 
     node = obj->nodesetval->nodeTab[0];
 
     if ((node->type == XML_TEXT_NODE) || (node->type == XML_ATTRIBUTE_NODE)) {
         nm_xml_char_t *xml_text = xmlNodeGetContent(node);
+
         nm_str_alloc_text(res, (char *) xml_text);
         xmlFree(xml_text);
     }
