@@ -6,6 +6,7 @@
 #include <nm_mon_daemon.h>
 #include <nm_vm_control.h>
 #include <nm_database.h>
+#include <nm_edit_vm.h>
 #include <nm_utils.h>
 #include <nm_form.h>
 
@@ -32,14 +33,19 @@ static void nm_api_reply(const char *request, nm_str_t *reply);
 
 /* API methods */
 static void nm_api_md_version(struct json_object *request, nm_str_t *reply);
-static void nm_api_md_nemu_version(struct json_object *request, nm_str_t *reply);
+static void
+nm_api_md_nemu_version(struct json_object *request, nm_str_t *reply);
 static void nm_api_md_auth(struct json_object *request, nm_str_t *reply);
 static void nm_api_md_vmlist(struct json_object *request, nm_str_t *reply);
 static void nm_api_md_vmstart(struct json_object *request, nm_str_t *reply);
 static void nm_api_md_vmstop(struct json_object *request, nm_str_t *reply);
 static void nm_api_md_vmforcestop(struct json_object *request, nm_str_t *reply);
-static void nm_api_md_vmgetconnectport(struct json_object *request, nm_str_t *reply);
-static void nm_api_md_vmgetsettings(struct json_object *request, nm_str_t *reply);
+static void
+nm_api_md_vmgetconnectport(struct json_object *request, nm_str_t *reply);
+static void
+nm_api_md_vmgetsettings(struct json_object *request, nm_str_t *reply);
+static void
+nm_api_md_vmsetsettings(struct json_object *request, nm_str_t *reply);
 
 static nm_api_ops_t nm_api[] = {
     { .method = "nemu_version",        .run = nm_api_md_nemu_version     },
@@ -50,7 +56,8 @@ static nm_api_ops_t nm_api[] = {
     { .method = "vm_stop",             .run = nm_api_md_vmstop           },
     { .method = "vm_force_stop",       .run = nm_api_md_vmforcestop      },
     { .method = "vm_get_connect_port", .run = nm_api_md_vmgetconnectport },
-    { .method = "vm_get_settings",     .run = nm_api_md_vmgetsettings    }
+    { .method = "vm_get_settings",     .run = nm_api_md_vmgetsettings    },
+    { .method = "vm_set_settings",     .run = nm_api_md_vmsetsettings    }
 };
 
 void *nm_api_server(void *ctx)
@@ -58,6 +65,7 @@ void *nm_api_server(void *ctx)
     struct pollfd fds[NM_API_POLL_MAXFDS];
     int sd, timeout, nfds = 1;
     SSL_CTX *tls_ctx = NULL;
+
     mon_data = ctx;
 
     SSL_library_init();
@@ -98,7 +106,8 @@ void *nm_api_server(void *ctx)
 
             /* check for unexpected result */
             if (fds[n].revents != POLLIN) {
-                nm_debug("%s: unexpected event: %d\n", __func__, fds[n].revents);
+                nm_debug("%s: unexpected event: %d\n",
+                        __func__, fds[n].revents);
                 goto out;
             }
 
@@ -217,6 +226,7 @@ static void nm_api_serve(SSL *tls)
     nread = SSL_read(tls, buf, sizeof(buf));
     if (nread > 0) {
         nm_str_t reply = NM_INIT_STR;
+
         buf[nread] = '\0';
         if (buf[nread - 1] == '\n') {
             buf[nread - 1] = '\0';
@@ -226,6 +236,7 @@ static void nm_api_serve(SSL *tls)
 
         if (reply.len) {
             int rc;
+
             rc = SSL_write(tls, reply.data, reply.len);
             if (rc <= 0) {
                 nm_debug("%s: %s\n", __func__,
@@ -358,12 +369,14 @@ static int nm_api_check_auth(struct json_object *request, nm_str_t *reply)
 
 #if OPENSSL_VERSION_NUMBER < 0x30000000L
     SHA256_CTX sha256;
+
     SHA256_Init(&sha256);
     SHA256_Update(&sha256, salted_pass.data, salted_pass.len);
     SHA256_Final(hash, &sha256);
 #else
     uint32_t md_len;
     EVP_MD_CTX *mdctx = EVP_MD_CTX_create();
+
     EVP_DigestInit_ex(mdctx, EVP_sha256(), NULL);
     EVP_DigestUpdate(mdctx, salted_pass.data, salted_pass.len);
     EVP_DigestFinal_ex(mdctx, hash, &md_len);
@@ -606,7 +619,7 @@ nm_api_md_vmgetconnectport(struct json_object *request, nm_str_t *reply)
         goto out;
     }
 
-    nm_str_format(&query, NM_VMCTL_GET_VNC_PORT_SQL, name_str);
+    nm_str_format(&query, NM_SQL_VMS_SELECT_VNC, name_str);
     nm_db_select(query.data, &res);
     port = nm_str_stoui(nm_vect_str(&res, 0), 10) + NM_STARTING_VNC_PORT;
     nm_str_format(reply, NM_API_RET_VAL_UINT, port);
@@ -685,6 +698,7 @@ nm_api_json_kv_append_arr_str(struct json_object *kv, const char *key,
 
     while (*values) {
         struct json_object *val = json_object_new_string(*values);
+
         if (val == NULL) {
             json_object_put(arr);
             return NULL;
@@ -744,8 +758,8 @@ nm_api_md_vmgetsettings(struct json_object *request, nm_str_t *reply)
     }
 
     /* CPU count */
-    if ((kv = nm_api_json_kv_str("value", nm_vect_str_ctx(&vm.main, NM_SQL_SMP)))
-            == NULL) {
+    if ((kv = nm_api_json_kv_str("value",
+                    nm_vect_str_ctx(&vm.main, NM_SQL_SMP))) == NULL) {
         nm_str_format(reply, NM_API_RET_ERR, "Internal error");
         goto out;
     }
@@ -761,7 +775,8 @@ nm_api_md_vmgetsettings(struct json_object *request, nm_str_t *reply)
 
     /* KVM status */
     if ((kv = nm_api_json_kv_bool("value",
-                    (nm_str_cmp_st(nm_vect_str(&vm.main,NM_SQL_KVM), NM_ENABLE)
+                    (nm_str_cmp_st(nm_vect_str(&vm.main,
+                                               NM_SQL_KVM), NM_ENABLE)
                      == NM_OK) ? TRUE : FALSE)) == NULL) {
         nm_str_format(reply, NM_API_RET_ERR, "Internal error");
         goto out;
@@ -770,7 +785,8 @@ nm_api_md_vmgetsettings(struct json_object *request, nm_str_t *reply)
 
     /* host CPU status */
     if ((kv = nm_api_json_kv_bool("value",
-                    (nm_str_cmp_st(nm_vect_str(&vm.main,NM_SQL_HCPU), NM_ENABLE)
+                    (nm_str_cmp_st(nm_vect_str(&vm.main,
+                                               NM_SQL_HCPU), NM_ENABLE)
                      == NM_OK) ? TRUE : FALSE)) == NULL) {
         nm_str_format(reply, NM_API_RET_ERR, "Internal error");
         goto out;
@@ -809,5 +825,189 @@ out:
     json_object_put(request);
 }
 
+static void
+nm_api_md_vmsetsettings(struct json_object *request, nm_str_t *reply)
+{
+    regex_t reg;
+    bool vm_exist = false;
+    nm_str_t query = NM_INIT_STR;
+    nm_str_t name_str = NM_INIT_STR;
+    nm_mon_vms_t *vms = mon_data->vms;
+    struct json_object *jreq;
+    nm_vm_t vm_new = NM_INIT_VM;
+    nm_vmctl_data_t vm_cur = NM_VMCTL_INIT_DATA;
+    int rc = nm_api_check_auth(request, reply);
+
+    memset(&reg, 0, sizeof(regex_t));
+
+    if (rc != NM_OK) {
+        goto out;
+    }
+
+    json_object_object_get_ex(request, "name", &jreq);
+    if (!jreq) {
+        nm_str_format(reply, NM_API_RET_ERR, "name param is missing");
+        goto out;
+    }
+
+    nm_str_format(&name_str, "%s", json_object_get_string(jreq));
+    for (size_t n = 0; n < vms->list->n_memb; n++) {
+        if (nm_str_cmp_ss(nm_mon_item_get_name(vms->list, n),
+                    &name_str) ==  NM_OK) {
+            vm_exist = true;
+            break;
+        }
+    }
+
+    if (!vm_exist) {
+        nm_str_format(reply, NM_API_RET_ERR, "VM does not exists");
+        goto out;
+    }
+
+    nm_vmctl_get_data(&name_str, &vm_cur);
+
+    json_object_object_get_ex(request, "smp", &jreq);
+    if (jreq) {
+        const char *regex = "^[0-9]+(:[0-9]+)?(:[0-9]+)?$";
+
+        if (regcomp(&reg, regex, REG_EXTENDED) != 0) {
+            nm_bug("%s: regcomp failed", __func__);
+        }
+
+        if (json_object_get_type(jreq) != json_type_string) {
+            nm_str_format(reply, NM_API_RET_ERR, "Wrong `smp` type");
+            goto out;
+        }
+
+        nm_str_format(&vm_new.cpus, "%s", json_object_get_string(jreq));
+        if (regexec(&reg, vm_new.cpus.data, 0, NULL, 0) != 0) {
+            nm_str_format(reply, NM_API_RET_ERR, "Incorrect `smp` value");
+            goto out;
+        }
+
+        if (nm_str_cmp_ss(nm_vect_str(&vm_cur.main, NM_SQL_SMP),
+                    &vm_new.cpus) != NM_OK) {
+            nm_str_format(&query, NM_SQL_VMS_UPDATE_SMP,
+                    vm_new.cpus.data, name_str.data);
+            nm_db_edit(query.data);
+        }
+    }
+
+    json_object_object_get_ex(request, "mem", &jreq);
+    if (jreq) {
+        if (json_object_get_type(jreq) != json_type_int) {
+            nm_str_format(reply, NM_API_RET_ERR, "Wrong `mem` type");
+            goto out;
+        }
+        nm_str_format(&vm_new.memo, "%d", json_object_get_int(jreq));
+        if (nm_str_cmp_ss(nm_vect_str(&vm_cur.main, NM_SQL_MEM),
+                    &vm_new.memo) != NM_OK) {
+            nm_str_format(&query, NM_SQL_VMS_UPDATE_MEM,
+                    vm_new.memo.data, name_str.data);
+            nm_db_edit(query.data);
+        }
+    }
+
+    json_object_object_get_ex(request, "kvm", &jreq);
+    if (jreq) {
+        bool cur_value = false;
+
+        if (json_object_get_type(jreq) != json_type_boolean) {
+            nm_str_format(reply, NM_API_RET_ERR, "Wrong `kvm` type");
+            goto out;
+        }
+
+        vm_new.kvm.enable = json_object_get_boolean(jreq);
+        if (nm_str_cmp_st(nm_vect_str(&vm_cur.main, NM_SQL_KVM),
+                    NM_ENABLE) == NM_OK) {
+            cur_value = true;
+        }
+
+        if (cur_value != vm_new.kvm.enable) {
+            nm_str_format(&query, NM_SQL_VMS_UPDATE_KVM,
+                    vm_new.kvm.enable ? NM_ENABLE : NM_DISABLE, name_str.data);
+            nm_db_edit(query.data);
+        }
+    }
+
+    json_object_object_get_ex(request, "hcpu", &jreq);
+    if (jreq) {
+        bool cur_value = false;
+
+        if (json_object_get_type(jreq) != json_type_boolean) {
+            nm_str_format(reply, NM_API_RET_ERR, "Wrong `hcpu` type");
+            goto out;
+        }
+
+        vm_new.kvm.hostcpu_enable = json_object_get_boolean(jreq);
+        if (nm_str_cmp_st(nm_vect_str(&vm_cur.main, NM_SQL_HCPU),
+                    NM_ENABLE) == NM_OK) {
+            cur_value = true;
+        }
+
+        if (cur_value != vm_new.kvm.hostcpu_enable) {
+            nm_str_format(&query, NM_SQL_VMS_UPDATE_HCPU,
+                    vm_new.kvm.hostcpu_enable ? NM_ENABLE : NM_DISABLE,
+                    name_str.data);
+            nm_db_edit(query.data);
+        }
+    }
+
+    json_object_object_get_ex(request, "netifs", &jreq);
+    if (jreq) {
+        if (json_object_get_type(jreq) != json_type_int) {
+            nm_str_format(reply, NM_API_RET_ERR, "Wrong `netifs` type");
+            goto out;
+        }
+        vm_new.ifs.count = json_object_get_int(jreq);
+        if ((vm_cur.ifs.n_memb / NM_IFS_IDX_COUNT) != vm_new.ifs.count) {
+            nm_edit_update_ifs(&query,
+                    &vm_cur, &vm_new, nm_form_get_last_mac());
+        }
+    }
+
+    json_object_object_get_ex(request, "disk_iface", &jreq);
+    if (jreq) {
+        const char **disk_drivers = nm_form_drive_drv;
+        bool found = false;
+
+        if (json_object_get_type(jreq) != json_type_string) {
+            nm_str_format(reply, NM_API_RET_ERR, "Wrong `disk_iface` type");
+            goto out;
+        }
+
+        nm_str_format(&vm_new.drive.driver, "%s", json_object_get_string(jreq));
+        while (*disk_drivers) {
+            if (nm_str_cmp_st(&vm_new.drive.driver, *disk_drivers) == NM_OK) {
+                found = true;
+                break;
+            }
+            disk_drivers++;
+        }
+
+        if (!found) {
+            nm_str_format(reply, NM_API_RET_ERR, "Wrong `disk_iface` value");
+            goto out;
+        }
+
+        if (nm_str_cmp_ss(nm_vect_str(&vm_cur.drives, NM_SQL_DRV_TYPE),
+                    &vm_new.drive.driver) != NM_OK) {
+            nm_str_format(&query, NM_SQL_DRIVES_UPDATE_DRV,
+                    vm_new.drive.driver.data, name_str.data);
+            nm_db_edit(query.data);
+        }
+    }
+
+    nm_str_format(reply, "%s", NM_API_RET_OK);
+
+out:
+    regfree(&reg);
+    nm_str_free(&query);
+    nm_str_free(&name_str);
+    nm_vmctl_free_data(&vm_cur);
+    nm_vm_free(&vm_new);
+    json_object_put(request);
+}
+
 #endif /* NM_WITH_REMOTE */
 /* vim:set ts=4 sw=4: */
